summaryrefslogtreecommitdiff
path: root/tests/SOCK_Connector_Test.cpp
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>1997-12-05 02:52:28 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>1997-12-05 02:52:28 +0000
commit9eb5ef9f999782a55d4b5e46d0302f2e4d93b996 (patch)
treeecb043450b6703858086ebec8666dbeeefe0c18d /tests/SOCK_Connector_Test.cpp
parentcdcee0a5c8c3c1fc69c280602f61dcd75fc522ac (diff)
downloadATCD-9eb5ef9f999782a55d4b5e46d0302f2e4d93b996.tar.gz
*** empty log message ***
Diffstat (limited to 'tests/SOCK_Connector_Test.cpp')
-rw-r--r--tests/SOCK_Connector_Test.cpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/tests/SOCK_Connector_Test.cpp b/tests/SOCK_Connector_Test.cpp
index 182b5ec356e..941bef2c410 100644
--- a/tests/SOCK_Connector_Test.cpp
+++ b/tests/SOCK_Connector_Test.cpp
@@ -93,8 +93,9 @@ fail_no_listener_nonblocking (void)
ACE_ASSERT (status == -1);
// On some systems, a failed connect to localhost will return
- // ECONNREFUSED directly, instead of EWOULDBLOCK. That is also fine.
- if (errno == EWOULDBLOCK || errno == ECONNREFUSED)
+ // ECONNREFUSED or ENETUNREACH directly, instead of
+ // EWOULDBLOCK. That is also fine.
+ if (errno == EWOULDBLOCK || errno == ECONNREFUSED || errno == ENETUNREACH)
{
if (sock.get_handle () != ACE_INVALID_HANDLE)
status = con.complete (sock);